<?php
require_once 'config.php';

// Check if user is logged in
if (!isset($_SESSION['telegram_user'])) {
    header("Location: index.php");
    exit();
}

$telegramId = $_SESSION['telegram_user']['id'];

// Get user data
try {
    $stmt = $pdo->prepare("SELECT * FROM users WHERE telegram_id = ?");
    $stmt->execute([$telegramId]);
    $user = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$user) {
        header("Location: logout.php");
        exit();
    }
    
    // Get balance
    $balance = $user['balance'];
    
    // Get withdrawal history
    $stmt = $pdo->prepare("
        SELECT * FROM withdrawals 
        WHERE user_id = ? 
        ORDER BY request_date DESC
        LIMIT 10
    ");
    $stmt->execute([$user['id']]);
    $withdrawals = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
} catch(PDOException $e) {
    die("Database error: " . $e->getMessage());
}

// Handle withdrawal request
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $method = $_POST['method'] ?? '';
    $amount = floatval($_POST['amount'] ?? 0);
    $wallet = trim($_POST['wallet'] ?? '');
    
    // Validate
    $errors = [];
    
    if (!in_array($method, ['bkash', 'nagad', 'rocket', 'usdt'])) {
        $errors[] = "Invalid payment method";
    }
    
    if ($amount < 1.00) {
        $errors[] = "Minimum withdrawal amount is BDT 1.00";
    }
    
    if ($amount > $balance) {
        $errors[] = "Insufficient balance";
    }
    
    if (empty($wallet)) {
        $errors[] = "Wallet address is required";
    }
    
    if (empty($errors)) {
        try {
            // Start transaction
            $pdo->beginTransaction();
            
            // Create withdrawal record
            $stmt = $pdo->prepare("
                INSERT INTO withdrawals (user_id, amount, method, wallet_address, status)
                VALUES (?, ?, ?, ?, 'pending')
            ");
            $stmt->execute([$user['id'], $amount, $method, $wallet]);
            
            // Deduct from balance
            $stmt = $pdo->prepare("UPDATE users SET balance = balance - ? WHERE id = ?");
            $stmt->execute([$amount, $user['id']]);
            
            // Commit transaction
            $pdo->commit();
            
            $_SESSION['success'] = "Withdrawal request submitted successfully!";
            header("Location: withdraw.php");
            exit();
        } catch(PDOException $e) {
            $pdo->rollBack();
            $_SESSION['error'] = "Error processing withdrawal: " . $e->getMessage();
            header("Location: withdraw.php");
            exit();
        }
    } else {
        $_SESSION['error'] = implode("<br>", $errors);
        header("Location: withdraw.php");
        exit();
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Withdraw Funds - Telegram Username Bot</title>
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@300;400;500;700&display=swap" rel="stylesheet">
    <style>
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
            font-family: 'Roboto', sans-serif;
        }
        body {
            background-color: #f5f5f5;
            color: #333;
        }
        .container {
            max-width: 500px;
            margin: 0 auto;
            background: white;
            min-height: 100vh;
            position: relative;
        }
        .header {
            background-color: #0088cc;
            color: white;
            padding: 15px;
            text-align: center;
        }
        .logo {
            font-size: 20px;
            font-weight: bold;
        }
        .main-content {
            padding: 15px;
        }
        .balance-section {
            background: white;
            border-radius: 10px;
            padding: 15px;
            margin-bottom: 15px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
            text-align: center;
        }
        .balance-amount {
            font-size: 24px;
            font-weight: bold;
            color: #0088cc;
            margin: 10px 0;
        }
        .withdraw-form {
            background: white;
            border-radius: 10px;
            padding: 15px;
            margin-bottom: 15px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        .form-title {
            font-weight: 500;
            margin-bottom: 15px;
        }
        .form-group {
            margin-bottom: 15px;
        }
        .form-label {
            display: block;
            margin-bottom: 5px;
            font-weight: 500;
        }
        .form-input, .form-select {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 5px;
            font-size: 16px;
        }
        .form-submit {
            background-color: #0088cc;
            color: white;
            border: none;
            padding: 12px;
            border-radius: 5px;
            font-weight: 500;
            cursor: pointer;
            display: block;
            width: 100%;
            font-size: 16px;
        }
        .history-section {
            background: white;
            border-radius: 10px;
            padding: 15px;
            margin-bottom: 15px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        .history-title {
            font-weight: 500;
            margin-bottom: 15px;
        }
        .history-item {
            display: flex;
            justify-content: space-between;
            padding: 10px 0;
            border-bottom: 1px solid #eee;
        }
        .history-amount {
            font-weight: 500;
        }
        .history-status {
            padding: 3px 8px;
            border-radius: 3px;
            font-size: 12px;
        }
        .status-pending {
            background-color: #fff3cd;
            color: #856404;
        }
        .status-approved {
            background-color: #d4edda;
            color: #155724;
        }
        .status-rejected {
            background-color: #f8d7da;
            color: #721c24;
        }
        .message {
            padding: 10px;
            margin-bottom: 15px;
            border-radius: 5px;
            text-align: center;
        }
        .success {
            background-color: #d4edda;
            color: #155724;
        }
        .error {
            background-color: #f8d7da;
            color: #721c24;
        }
        .footer {
            position: fixed;
            bottom: 0;
            width: 100%;
            max-width: 500px;
            background-color: #0088cc;
            display: flex;
            justify-content: space-around;
            padding: 10px 0;
        }
        .footer-btn {
            color: white;
            text-decoration: none;
            text-align: center;
            font-size: 12px;
        }
        .footer-icon {
            font-size: 20px;
            margin-bottom: 5px;
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
            <div class="logo">Withdraw Funds</div>
        </div>
        
        <div class="main-content">
            <?php if (isset($_SESSION['success'])): ?>
                <div class="message success"><?php echo $_SESSION['success']; unset($_SESSION['success']); ?></div>
            <?php endif; ?>
            
            <?php if (isset($_SESSION['error'])): ?>
                <div class="message error"><?php echo $_SESSION['error']; unset($_SESSION['error']); ?></div>
            <?php endif; ?>
            
            <div class="balance-section">
                <div>Available Balance</div>
                <div class="balance-amount"><?php echo formatCurrency($balance); ?></div>
                <div>Minimum Withdrawal: BDT 1.00</div>
            </div>
            
            <div class="withdraw-form">
                <div class="form-title">Request Withdrawal</div>
                <form method="POST">
                    <div class="form-group">
                        <label class="form-label" for="method">Payment Method</label>
                        <select class="form-select" id="method" name="method" required>
                            <option value="">Select Method</option>
                            <option value="bkash">bKash</option>
                            <option value="nagad">Nagad</option>
                            <option value="rocket">Rocket</option>
                            <option value="usdt">USDT (TRC20)</option>
                        </select>
                    </div>
                    
                    <div class="form-group">
                        <label class="form-label" for="amount">Amount (BDT)</label>
                        <input type="number" class="form-input" id="amount" name="amount" 
                               min="1.00" max="<?php echo $balance; ?>" step="0.01" 
                               placeholder="Enter amount" required>
                    </div>
                    
                    <div class="form-group">
                        <label class="form-label" for="wallet">Wallet Address</label>
                        <input type="text" class="form-input" id="wallet" name="wallet" 
                               placeholder="Enter wallet address" required>
                    </div>
                    
                    <button type="submit" class="form-submit">Submit Withdrawal</button>
                </form>
            </div>
            
            <div class="history-section">
                <div class="history-title">Withdrawal History</div>
                
                <?php if (!empty($withdrawals)): ?>
                    <?php foreach ($withdrawals as $withdrawal): ?>
                        <div class="history-item">
                            <div>
                                <div><?php echo strtoupper($withdrawal['method']); ?></div>
                                <div style="font-size: 12px; color: #666;">
                                    <?php echo date('d M Y', strtotime($withdrawal['request_date'])); ?>
                                </div>
                            </div>
                            <div style="text-align: right;">
                                <div class="history-amount"><?php echo formatCurrency($withdrawal['amount']); ?></div>
                                <div class="history-status status-<?php echo $withdrawal['status']; ?>">
                                    <?php echo ucfirst($withdrawal['status']); ?>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                <?php else: ?>
                    <div style="text-align: center; padding: 10px; color: #666;">
                        No withdrawal history
                    </div>
                <?php endif; ?>
            </div>
        </div>
        
        <div class="footer">
            <a href="index.php" class="footer-btn">
                <div class="footer-icon">🏠</div>
                <div>Home</div>
            </a>
            <a href="earn.php" class="footer-btn">
                <div class="footer-icon">💰</div>
                <div>Earn</div>
            </a>
            <a href="withdraw.php" class="footer-btn">
                <div class="footer-icon">💳</div>
                <div>Withdraw</div>
            </a>
            <a href="profile.php" class="footer-btn">
                <div class="footer-icon">👤</div>
                <div>Profile</div>
            </a>
        </div>
    </div>
</body>
</html>